using System;
using System.Text;
using Zcu.Mve.Core;
using Zcu.Mve.Numerics;

namespace Zcu.Mve.Numerics
{
	/// <summary>
	/// A conversion module that transforms a MveInt value to a Scalar value
	/// </summary>
	[ModuleInfo("Libor Va", "A conversion module that transforms a MveInt value to a Scalar value")]
	[PortInfo("MveInt", "An MveInt value to be converted")]
	[PortInfo("Scalar", "The resulting Scalar value")]
    class MveInt2ScalarConverter:Module
    {
		/// <summary>
		/// Default constructor, adds input and output ports.
		/// </summary>
        public MveInt2ScalarConverter()
        {
            AddInPort("MveInt", typeof(MveInt));
            AddOutPort("Scalar", typeof(Scalar));
        }

        private Scalar result;

		/// <summary>
		/// Performs the data conversion. Standard int->double typecast operator is used to obtain the resulting value.
		/// </summary>
        public override void Execute()
        {
            if (!IsDataSame("MveInt"))
            {
                MveInt i = (MveInt)GetInput("MveInt");
                result = new Scalar((double)i);
                SetOutput("Scalar", result);
            }
            else
            {
                SetOutput("Scalar", result, true);
            }
        }
    }
}
