using System;
using Zcu.Mve.Core;
using System.ComponentModel;

namespace Zcu.Mve.Numerics
{
	/// <summary>
	/// A source module for MveInt
	/// </summary>
	[ModuleInfo("Libor Va", "A source module for MveInt")]
	[PortInfo("MveInt", "Resulting MveInt")]
	public class MveIntSource:Module
	{
		private MveInt output;
		private int val;
		private bool paramsChanged = true;

        /// <summary>
        /// Integer value that will be set as output.
        /// </summary>        
        [Description("Integer value that will be used as output of the module")]
		public int Value
		{
			get{return(val);}
			set
			{
				this.val = value;
				this.paramsChanged = true;
			}
		}

        /// <summary>
        /// Default constructor.
        /// </summary>
		public MveIntSource()
		{
			AddOutPort("MveInt",typeof(MveInt));
		}

        /// <summary>
        /// Checks wether value property was changed and sets the output accordingly.
        /// If value was not changed since the last run then dataSame is set to true.
        /// </summary>
		public override void Execute()
		{
			if (paramsChanged)
			{
				output = new MveInt(this.val);
				SetOutput("MveInt",output,false);
				paramsChanged = false;
			}
			else
			{
				SetOutput("MveInt",output,true);
			}
		}

	}
}
