using System;
using Zcu.Mve.Core;

namespace Zcu.Mve.Numerics
{
	/// <summary>
	/// A module that adds two MveInt numbers
	/// </summary>
	/// 
	[ModuleInfo("Libor Va","A module that adds two MveInt numbers")]
	[PortInfo("A", "First operand of the addition")]
	[PortInfo("B", "Second operand of the addition")]
	[PortInfo("Sum", "Resulting sum")]
	public class MveIntSum:Module
	{
		MveInt output;
		bool outputSet = false;

        /// <summary>
        /// Default constructor
        /// </summary>
		public MveIntSum()
		{
			AddInPort("A",typeof(MveInt));
			AddInPort("B",typeof(MveInt));
			AddOutPort("Sum", typeof(MveInt));
		}
		

        /// <summary>
        /// Reads input data and sets sum as output.
        /// If inputs are not changed, then the output is not computed and dataSame is set to true.
        /// </summary>
		public override void Execute()
		{
			if (IsAllDataSame()&&(outputSet))
			{
				SetOutput("Sum",output,true);
			}
			else
			{
				MveInt a = (MveInt)GetInput("A");
				MveInt b = (MveInt)GetInput("B");
				output = new MveInt(a.Value+b.Value);
				outputSet = true;
				SetOutput("Sum",output,false);
			}
		}		
	}
}

