using System;
using System.Text;
using Zcu.Mve.Core;
using Zcu.Mve.Numerics;

namespace Zcu.Mve.Numerics
{
	/// <summary>
	/// Scalar multiplication module.
	/// </summary>
	[ModuleInfo("Libor Va", "Scalar multiplication module.")]
	[PortInfo("Arg1", "Scalar value of the first argument.")]
	[PortInfo("Arg2", "Scalar value of the second argument.")]
	[PortInfo("Result", "Result value of the multiplication.")]
    class ScalarMult:Module
    {
        public ScalarMult()
        {
            AddInPort("Arg1", typeof(Scalar));
            AddInPort("Arg2", typeof(Scalar));
            AddOutPort("Result", typeof(Scalar));
        }

        Scalar result;

		/// <summary>
		/// Performs the multiplication. If no inputs are changed since the last run, then the last result is returned immediately.
		/// </summary>
        public override void Execute()
        {
            if (!IsAllDataSame())
            {
                Scalar s1 = (Scalar)GetInput("Arg1");
                Scalar s2 = (Scalar)GetInput("Arg2");
                result = new Scalar(s1.Value * s2.Value);
                SetOutput("Result", result);
            }
            else
            {
                SetOutput("Result", result, true);
            }
        }
    }
}
