using System;
using Zcu.Mve.Core;

namespace Zcu.Mve.Numerics
{
	/// <summary>
	/// A module that composes a VectorND from input scalar values
	/// </summary>
	[ModuleInfo("Libor Va", "A module that composes a VectorND from input scalar values")]
	[PortInfo("Vector", "Resulting VectorND")]
	[PortInfo("V1", "First element of the vector, if an input is connected to this port an additional port appears that can accept the next element of the vector.")]
	public class VectorComposer:Module
	{
		private int portCount = 1;

		private VectorND output;

		private bool paramsChanged = true;

        /// <summary>
        /// Default constructor.
        /// </summary>
		public VectorComposer()
		{
			AddOutPort("Vector",typeof(VectorND));
			AddInPort("V1",typeof(Scalar),true);
			this.OnConnectEvent +=new ConnectCallBack(VectorComposer_OnConnectEvent);
			this.OnDisconnectEvent += new DisconnectCallBack(VectorComposer_OnDisconnectEvent);
		}

		private void VectorComposer_OnConnectEvent(object source, OutPort portFrom, InPort portTo, out bool allowed)
		{
			if (portTo == this.GetInPort("V"+portCount))
			{				
				portCount++;
				this.AddInPort("V"+portCount,typeof(Scalar),false);
			}
			allowed = true;
			paramsChanged = true;
		}

		private void VectorComposer_OnDisconnectEvent(object source, InPort portTo, out bool allowed)
		{
            allowed = true;
            if (portTo == this.GetInPort("V"+(portCount-1)))
			{
				int i = portCount-1;
				while ((GetInPort("V"+i).Link == null)||(i!=1))
				{
					RemoveInPort("V"+(i+1));
					portCount--;
					i--;
				}
			}			
			paramsChanged = true;
		}

        /// <summary>
        /// Constructs a vector from input values.
        /// If no ports were added or removed since the last run and all data is same, then the same vector is set as output
        /// and DataSame is set to true.
        /// </summary>
		public override void Execute()
		{
			if ((!IsAllDataSame())||(paramsChanged))
			{
				double[] vector = new double[portCount-1];
				for (int i = 1;i<portCount;i++)
				{
					vector[i-1] = (double)((Scalar)GetInput("V"+i));
				}
				output = new VectorND(vector);
				SetOutput("Vector",output,false);
				paramsChanged = false;
			}
			else
			{
				SetOutput("Vector",output,true);
			}
		}
	}
}
